@@ -570,7 +570,13 @@ QDate FlatpakResource::releaseDate() const
 
 QString FlatpakResource::sourceIcon() const
 {
-    const auto iconUrl = qobject_cast<FlatpakBackend*>(backend())->sources()->sourceById(origin())->data(FlatpakSourcesBackend::IconUrlRole).toString();
+    const auto sourceItem = qobject_cast<FlatpakBackend*>(backend())->sources()->sourceById(origin());
+    if (!sourceItem) {
+        qWarning() << "Could not find source " << origin();
+        return QStringLiteral("flatpak-discover");
+    }
+
+    const auto iconUrl = sourceItem->data(FlatpakSourcesBackend::IconUrlRole).toString();
     if (iconUrl.isEmpty())
         return QStringLiteral("flatpak-discover");
     return iconUrl;
@@ -585,3 +591,11 @@ QStringList FlatpakResource::extends() const
 {
     return m_appdata.extends();
 }
+
+QSet<QString> FlatpakResource::alternativeAppstreamIds() const
+{
+    const AppStream::Provided::Kind AppStream_Provided_KindId = (AppStream::Provided::Kind) 12; //Should be AppStream::Provided::KindId when released
+    const auto ret = m_appdata.provided(AppStream_Provided_KindId).items();
+
+    return QSet<QString>(ret.begin(), ret.end());
+}
