@@ -136,6 +136,13 @@ QString AppPackageKitResource::appstreamId() const
     return m_appdata.id();
 }
 
+QSet<QString> AppPackageKitResource::alternativeAppstreamIds() const
+{
+    const AppStream::Provided::Kind AppStream_Provided_KindId = (AppStream::Provided::Kind) 12; //Should be AppStream::Provided::KindId when released
+    const auto ret = m_appdata.provided(AppStream_Provided_KindId).items();
+    return QSet<QString>(ret.begin(), ret.end());
+}
+
 QUrl AppPackageKitResource::homepage()
 {
     return m_appdata.url(AppStream::Component::UrlKindHomepage);
@@ -224,7 +231,7 @@ void AppPackageKitResource::invokeApplication() const
             const QStringList exes = m_appdata.provided(AppStream::Provided::KindBinary).items();
             const auto packageExecutables = kFilter<QStringList>(exes, [filenames](const QString &exe) { return filenames.contains(QLatin1Char('/') + exe); });
             if (!packageExecutables.isEmpty()) {
-                QProcess::startDetached(exes.constFirst());
+                QProcess::startDetached(exes.constFirst(), QStringList());
                 return;
             } else {
                 const auto locations = QStandardPaths::standardLocations(QStandardPaths::ApplicationsLocation);
